package Bundle::Pipe;

$VERSION = "0.01";

__END__

=head1 NAME

Bundle::Pipe - Additional Tubes for the Pipe module

=head1 SYNOPSIS

Install:

 perl -MCPAN -e 'install Bundle::Pipe'

Or:

 $> cpan
 cpan> install Bundle::Pipe
 cpan> quit

=begin _for_CPAN_only

CONTENTS is the actually listing of the modules that is used by CPAN.pm to install.
Humans can skip this part of the document.

=head1 CONTENTS

Pipe

Pipe::Tube::Csv

=end _for_CPAN_only

Specifically in the case of this module it is less important to have a log of the

=head1 AUTHOR

 Gabor Szabo <gabor@pti.co.il>

=head1 COPYRIGHT

 Copyright 2006 by Gabor Szabo L<http://www.pti.co.il>.

 This program is free software; you can redistribute it and/or
 modify it under the same terms as Perl itself.

=cut 

